@@ -15,6 +15,9 @@ class MolDataUtils:
     def __init__(self, mol_data_fp: str):
         self._mol_df = pd.read_csv(mol_data_fp, sep='\t', encoding='utf-8')
 
+    def num_mol(self) -> int:
+        return len(self._mol_df)
+
     def get_mol_with_code(self, mol_code: str) -> Mol:
         query_df = self._mol_df.query(f"mol_code=='{mol_code}'")
         if len(query_df) == 0:
