@@ -19,6 +19,9 @@ class RxnDataUtils:
         self._rxn_df = pd.read_csv(rxn_data_fp, sep='\t', encoding='utf-8')
         self._mol_data_utils = mol_data_utils
 
+    def num_rxn(self) -> int:
+        return len(self._rxn_df)
+
     def init_mols(self, rxn: Rxn):
         rxn.reactants = [self._mol_data_utils.get_mol_with_code(mol_code) for mol_code in rxn.reactants_codes]
         rxn.products = [self._mol_data_utils.get_mol_with_code(rxn.product_code)]
